Index: trunk/src/helpers/_test_exeh.c
===================================================================
--- trunk/src/helpers/_test_exeh.c	(revision 263)
+++ trunk/src/helpers/_test_exeh.c	(revision 265)
@@ -101,5 +101,5 @@
         if (arc)
         {
-            printf("exeh: Error %d occured with \"%s\".\n", arc, argv[1]);
+            printf("exeh: Error %d occurred with \"%s\".\n", arc, argv[1]);
         }
     }
Index: trunk/src/helpers/_test_map.c
===================================================================
--- trunk/src/helpers/_test_map.c	(revision 263)
+++ trunk/src/helpers/_test_map.c	(revision 265)
@@ -96,5 +96,5 @@
     else
     {
-        printf("Error %d occured at line %d\n", rc, ulLineError);
+        printf("Error %d occurred at line %d\n", rc, ulLineError);
         printf("Line buf: \"%s\"", szLineBuf);
     }
Index: trunk/src/helpers/cctl_chart.c
===================================================================
--- trunk/src/helpers/cctl_chart.c	(revision 263)
+++ trunk/src/helpers/cctl_chart.c	(revision 265)
@@ -997,5 +997,5 @@
  *      paRegions to NULL.
  *
- *      This returns NULLHANDLE if an error occured.
+ *      This returns NULLHANDLE if an error occurred.
  *      This can mean the following:
  *
Index: trunk/src/helpers/cnrh.c
===================================================================
--- trunk/src/helpers/cnrh.c	(revision 263)
+++ trunk/src/helpers/cnrh.c	(revision 265)
@@ -1188,5 +1188,5 @@
  *      to remove the source emphasis for preccSource again.
  *
- *      This function returns FALSE if an error occured.
+ *      This function returns FALSE if an error occurred.
  *
  *@@added V0.9.0 [umoeller]
Index: trunk/src/helpers/dialog.c
===================================================================
--- trunk/src/helpers/dialog.c	(revision 263)
+++ trunk/src/helpers/dialog.c	(revision 265)
@@ -3258,5 +3258,5 @@
     {
         CHAR szErr[300];
-        sprintf(szErr, "Error %d occured in " __FUNCTION__ ".", arc);
+        sprintf(szErr, "Error %d occurred in " __FUNCTION__ ".", arc);
         winhDebugBox(hwndOwner,
                      "Error in Dialog Manager",
@@ -3381,5 +3381,5 @@
     {
         CHAR szErr[300];
-        sprintf(szErr, "Error %d occured in " __FUNCTION__ ".", arc);
+        sprintf(szErr, "Error %d occurred in " __FUNCTION__ ".", arc);
         winhDebugBox(NULLHANDLE,
                      "Error in Dialog Manager",
Index: trunk/src/helpers/dosh.c
===================================================================
--- trunk/src/helpers/dosh.c	(revision 263)
+++ trunk/src/helpers/dosh.c	(revision 265)
@@ -3261,5 +3261,5 @@
  *
  *      This returns the APIRET of DosOpen and DosRead.
- *      If any error occured, no buffer was allocated.
+ *      If any error occurred, no buffer was allocated.
  *      Otherwise, you should free() the buffer when
  *      no longer needed.
Index: trunk/src/helpers/dosh2.c
===================================================================
--- trunk/src/helpers/dosh2.c	(revision 263)
+++ trunk/src/helpers/dosh2.c	(revision 265)
@@ -327,5 +327,5 @@
  *      also, if one is specified.
  *
- *@@changed V0.9.9 (2001-04-04) [umoeller]: this returned an error even if none occured, fixed
+ *@@changed V0.9.9 (2001-04-04) [umoeller]: this returned an error even if none occurred, fixed
  */
 
Index: trunk/src/helpers/gpih.c
===================================================================
--- trunk/src/helpers/gpih.c	(revision 263)
+++ trunk/src/helpers/gpih.c	(revision 265)
@@ -2547,5 +2547,5 @@
  *      --  GPI_OK
  *      --  GPI_HITS: correlate hits
- *      --  GPI_ERROR: error occured (probably either hbmSource not free
+ *      --  GPI_ERROR: error occurred (probably either hbmSource not free
  *                     or no bitmap selected into hpsTarget)
  *
Index: trunk/src/helpers/memdebug_win.c
===================================================================
--- trunk/src/helpers/memdebug_win.c	(revision 263)
+++ trunk/src/helpers/memdebug_win.c	(revision 265)
@@ -394,5 +394,5 @@
             CHAR        szMsg[1000];
             sprintf(szMsg,
-                    "Crash occured at object #%d out of %d",
+                    "Crash occurred at object #%d out of %d",
                     cHeapItems,
                     G_cHeapItems);
Index: trunk/src/helpers/syssound.c
===================================================================
--- trunk/src/helpers/syssound.c	(revision 263)
+++ trunk/src/helpers/syssound.c	(revision 265)
@@ -389,5 +389,5 @@
  *      this sets a system sound in MMPM.INI by
  *      calling sndWriteSoundData.
- *      Returns FALSE if an error occured.
+ *      Returns FALSE if an error occurred.
  *
  *      See sndQuerySystemSound for the parameters.
Index: trunk/src/helpers/timer.c
===================================================================
--- trunk/src/helpers/timer.c	(revision 263)
+++ trunk/src/helpers/timer.c	(revision 265)
@@ -636,5 +636,5 @@
  *      with hwnd). Use tmrStopXTimer to stop the timer.
  *
- *      Returns 0 if an error occured. It is thus
+ *      Returns 0 if an error occurred. It is thus
  *      invalid to specify a timer ID of 0.
  *
Index: trunk/src/helpers/xml.c
===================================================================
--- trunk/src/helpers/xml.c	(revision 263)
+++ trunk/src/helpers/xml.c	(revision 265)
@@ -2619,5 +2619,5 @@
  *      -- ERROR_INVALID_PARAMETER
  *
- *      -- ERROR_DOM_PARSING: an @expat parsing error occured.
+ *      -- ERROR_DOM_PARSING: an @expat parsing error occurred.
  *         This might also be memory problems.
  *         With this error code, you will find specific

Index: trunk/src/helpers/except.c
===================================================================
--- trunk/src/helpers/except.c	(revision 263)
+++ trunk/src/helpers/except.c	(revision 265)
@@ -53,5 +53,5 @@
  +              CATCH(excptid)
  +              {
- +                  ....        // exception occured: react here
+ +                  ....        // exception occurred: react here
  +              } END_CATCH();  // always needed!
  +          } // end of your_func
@@ -140,5 +140,5 @@
  +
  +              if (fSemOwned)
- +                  // this gets executed always, even if an exception occured
+ +                  // this gets executed always, even if an exception occurred
  +                  DosReleaseMutexSem(hmtx);
  +          } // end of your_func
@@ -720,5 +720,5 @@
             // *** instruction
 
-            fprintf(file, "Instruction pointer (where exception occured):\n    CS:EIP = %04lX:%08lX  ",
+            fprintf(file, "Instruction pointer (where exception occurred):\n    CS:EIP = %04lX:%08lX  ",
                     pContextRec->ctx_SegCs,
                     pContextRec->ctx_RegEip);
Index: trunk/src/helpers/prfh2.c
===================================================================
--- trunk/src/helpers/prfh2.c	(revision 263)
+++ trunk/src/helpers/prfh2.c	(revision 265)
@@ -99,5 +99,5 @@
     if (fLog)
     {
-        fprintf(fLog, "    Error occured: %s\n    Return code: %s (%lu)\n",
+        fprintf(fLog, "    Error occurred: %s\n    Return code: %s (%lu)\n",
                 pszErrorString,
                     (ulrc == MBID_ABORT) ? "MBID_ABORT"
@@ -127,5 +127,5 @@
 {
     CHAR szError2[2000];
-    sprintf(szError2, "An error occured copying the profile %s: \n%s",
+    sprintf(szError2, "An error occurred copying the profile %s: \n%s",
             pcszINI, pszErrorString);
     return prfhINIError(ulOptions, fLog, fncbError, szError2);
@@ -330,5 +330,5 @@
 
                 if (ulErrorStatus == MBID_IGNORE)
                     // error occured, but user pressed "Ignore":
                     // skip this app
                     ulErrorStatus = MBID_NOERROR;
@@ -343,5 +343,5 @@
 
         } while (ulErrorStatus == MBID_RETRY);
-    } // end if (ulErrorOccured == MBID_NOERROR)
+    } // end if (ulErrorOccurred == MBID_NOERROR)
 
     if (fLog)
@@ -358,5 +358,5 @@
     }
 
-    return (ulErrorStatus == MBID_NOERROR); // FALSE if error occured
+    return (ulErrorStatus == MBID_NOERROR); // FALSE if error occurred
 }
 
@@ -391,8 +391,8 @@
     // the following flag may be one of the following:
     //        MBID_NOERROR--- everything's fine, continue
-    //        MBID_IGNORE --- error occured, but ignore
-    //        MBID_RETRY  --- error occured, but retry
-    //        MBID_ABORT  --- error occured, abort saving
-    ULONG   ulErrorOccured = MBID_IGNORE;
+    //        MBID_IGNORE --- error occurred, but ignore
+    //        MBID_RETRY  --- error occurred, but retry
+    //        MBID_ABORT  --- error occurred, abort saving
+    ULONG   ulErrorOccurred = MBID_IGNORE;
 
     if (fLog)
@@ -408,8 +408,8 @@
 
     if (!brc)
-        ulErrorOccured = prfhINIError(MB_CANCEL, fLog, fncbError,
+        ulErrorOccurred = prfhINIError(MB_CANCEL, fLog, fncbError,
                                       "Error querying system profiles size.");
 
-    if (ulErrorOccured == MBID_IGNORE)
+    if (ulErrorOccurred == MBID_IGNORE)
     {
         Profiles.pszUserName  = (PSZ)malloc(Profiles.cchUserName);
@@ -418,16 +418,16 @@
              || (Profiles.pszUserName == NULL)
            )
-            ulErrorOccured = prfhINIError(MB_CANCEL, fLog, fncbError,
+            ulErrorOccurred = prfhINIError(MB_CANCEL, fLog, fncbError,
                     "Error allocating memory (1).");
     }
 
-    if (ulErrorOccured == MBID_IGNORE)
+    if (ulErrorOccurred == MBID_IGNORE)
     {
         if (!PrfQueryProfile(hab, &Profiles))
-            ulErrorOccured = prfhINIError(MB_CANCEL, fLog, fncbError,
+            ulErrorOccurred = prfhINIError(MB_CANCEL, fLog, fncbError,
                     "Error querying profiles (2).");
     }
 
-    if (ulErrorOccured == MBID_IGNORE)
+    if (ulErrorOccurred == MBID_IGNORE)
     {
         if (fLog)
@@ -463,9 +463,9 @@
         {
             // abort, since prfhCopyProfile already has error handling
-            ulErrorOccured = MBID_ABORT;
+            ulErrorOccurred = MBID_ABORT;
         }
     }
 
-    if (ulErrorOccured == MBID_IGNORE)
+    if (ulErrorOccurred == MBID_IGNORE)
     {
         // create OS2.XFL
@@ -483,5 +483,5 @@
         {
             // abort, since prfhCopyProfile already has error handling
-            ulErrorOccured = MBID_ABORT;
+            ulErrorOccurred = MBID_ABORT;
         }
     }
@@ -492,11 +492,11 @@
      */
 
-    if (ulErrorOccured == MBID_IGNORE)
+    if (ulErrorOccurred == MBID_IGNORE)
     {
         do
         {
-            ulErrorOccured = MBID_IGNORE; // if we have a retry in the do-while loop
-
-            if (ulErrorOccured == MBID_IGNORE)
+            ulErrorOccurred = MBID_IGNORE; // if we have a retry in the do-while loop
+
+            if (ulErrorOccurred == MBID_IGNORE)
             {
                 // attrib -r -s -h -a OS2SYS.BAK
@@ -536,8 +536,8 @@
 
                 if (arc)
-                    ulErrorOccured = prfhINIError(MB_ABORTRETRYIGNORE, fLog, fncbError, "Error moving original system profile to backup.");
+                    ulErrorOccurred = prfhINIError(MB_ABORTRETRYIGNORE, fLog, fncbError, "Error moving original system profile to backup.");
             }
 
-            if (ulErrorOccured == MBID_IGNORE)
+            if (ulErrorOccurred == MBID_IGNORE)
             {
                 if (fLog)
@@ -548,7 +548,7 @@
                     fprintf(fLog, "    rc: %lu\n", arc);
                 if (arc)
-                    ulErrorOccured = prfhINIError(MB_ABORTRETRYIGNORE, fLog, fncbError, "Error moving newly created profile to system profile.");
+                    ulErrorOccurred = prfhINIError(MB_ABORTRETRYIGNORE, fLog, fncbError, "Error moving newly created profile to system profile.");
             }
-        } while (ulErrorOccured == MBID_RETRY);
+        } while (ulErrorOccurred == MBID_RETRY);
     }
 
@@ -558,11 +558,11 @@
      */
 
-    if (ulErrorOccured == MBID_IGNORE)
+    if (ulErrorOccurred == MBID_IGNORE)
     {
         do
         {
-            ulErrorOccured = MBID_IGNORE; // if we have a retry in the do-while loop
-
-            if (ulErrorOccured == MBID_IGNORE)
+            ulErrorOccurred = MBID_IGNORE; // if we have a retry in the do-while loop
+
+            if (ulErrorOccurred == MBID_IGNORE)
             {
                 // attrib -r -s -h -a OS2.BAK
@@ -601,8 +601,8 @@
 
                 if (arc)
-                    ulErrorOccured = prfhINIError(MB_ABORTRETRYIGNORE, fLog, fncbError, "Error moving original user profile to backup.");
+                    ulErrorOccurred = prfhINIError(MB_ABORTRETRYIGNORE, fLog, fncbError, "Error moving original user profile to backup.");
             }
 
-            if (ulErrorOccured == MBID_IGNORE)
+            if (ulErrorOccurred == MBID_IGNORE)
             {
                 // move OS2.XFL OS2.INI
@@ -616,12 +616,12 @@
 
                 if (arc)
-                    ulErrorOccured = prfhINIError(MB_ABORTRETRYIGNORE, fLog, fncbError, "Error moving newly created profile to user profile.");
+                    ulErrorOccurred = prfhINIError(MB_ABORTRETRYIGNORE, fLog, fncbError, "Error moving newly created profile to user profile.");
             }
-        } while (ulErrorOccured == MBID_RETRY);
+        } while (ulErrorOccurred == MBID_RETRY);
     }
 
     // DosExitCritSec();
 
-    if (ulErrorOccured != MBID_IGNORE)
+    if (ulErrorOccurred != MBID_IGNORE)
     {
         DosMove(szSysBackup, Profiles.pszSysName);
@@ -637,5 +637,5 @@
         fprintf(fLog, "  Done with prfhSaveINIs\n");
 
-    if (ulErrorOccured != MBID_IGNORE)
+    if (ulErrorOccurred != MBID_IGNORE)
         return 999;
     else
@@ -330,5 +330,5 @@
 
                 if (ulErrorStatus == MBID_IGNORE)
-                    // error occured, but user pressed "Ignore":
+                    // error occurred, but user pressed "Ignore":
                     // skip this app
                     ulErrorStatus = MBID_NOERROR;